==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableMap__24UnmodifiableEntrySet.h <==
// final class java.util.Collections$UnmodifiableMap$UnmodifiableEntrySet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class a50758806c77427e java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableSet

#include "java/util/Collections__24UnmodifiableSet.h"

#ifndef _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_
#define _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs {
    _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object {
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableMap__24UnmodifiableEntrySet.h <==
// final class java.util.Collections$UnmodifiableMap$UnmodifiableEntrySet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2126b28aee607999 java_util_Collections__24UnmodifiableCollection
// @dep_class a50758806c77427e java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet
// @dep_class aec2ea3fc69f0e47 java_util_Collections__24UnmodifiableSet

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableSet

#include "java/util/Collections__24UnmodifiableSet.h"

#ifndef _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_
#define _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Iterator$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object;

typedef struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$fields_struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method$_init$4239edc3ba8b9760(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods {
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableCollection$vmethods	java_util_Collections__24UnmodifiableCollection;
	_jc_java_util_Collections__24UnmodifiableSet$vmethods	java_util_Collections__24UnmodifiableSet;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vmethods	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs {
    _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_refs	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
    _jc_java_util_Collections__24UnmodifiableSet$sub_refs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_refs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableCollection$sub_nonrefs	java_util_Collections__24UnmodifiableCollection;
    _jc_java_util_Collections__24UnmodifiableSet$sub_nonrefs	java_util_Collections__24UnmodifiableSet;
    _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$sub_nonrefs	java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$object {
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$vtype _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableMap__24UnmodifiableEntrySet_H_ */
